BinaryMatchGenerator class

BinaryMatchGenerator is a generator that generates the source code of a logical expression (predicate) for matching, implementing balanced binary search.

Constructors

BinaryMatchGenerator({required String name, required Ranges ranges})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The variable name being checked in the generated code (e.g., 'c').
final
ranges Ranges
The list of ranges to test.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() String
Generates source code for binary matching.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited