DfaState<T> class

Constructors

DfaState(int id, Set<NfaState<T>> states)

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
states Set<NfaState<T>>
final
transitions List<(Range, DfaState<T>)>
final

Methods

addTransition(Range range, DfaState<T> state) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override