IntervalCombiner<T> class

Constructors

IntervalCombiner({required List<Interval<T>> intervals})

Properties

hashCode int
The hash code for this object.
no setterinherited
intervals List<Interval<T>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

combine() List<Interval<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited