Nfa<T> class

Constructors

Nfa({required NfaState<T> accept, required NfaState<T> initial})

Properties

accept NfaState<T>
final
hashCode int
The hash code for this object.
no setterinherited
initial NfaState<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({NfaState<T>? accept, NfaState<T>? initial}) Nfa<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited