SparseList<E> class

Constructors

SparseList()
SparseList.fromMap(Map<Range, E> map)

Properties

hashCode int
The hash code for this object.
no setterinherited
intervals List<Interval<E>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Range range, Set<E> values) → void
addAll(List<(Range, Set<E>)> elements) → void
getValues(int index) Set<E>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited