TrieNode<T> class

Constructors

TrieNode()

Properties

backReferences Set<TrieNode<T>>
final
children Map<Range, TrieNode<T>>
final
hashCode int
The hash code for this object.
no setterinherited
parents Map<Range, Set<TrieNode<T>>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
states Set<DfaState<T>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited