NfaState<T> class
Properties
-
data
→ Set<
T> -
final
-
epsilonTransitions
→ List<
NfaState< T> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transitions
→ List<
(Ranges, NfaState< T> )> -
final
Methods
-
addEpsilonTransition(
NfaState< T> state) → void -
addTransition(
Ranges ranges, NfaState< T> state) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited